@@ -11,14 +11,17 @@ mod stats;
 
 pub use self::actions::{
     TcAction, TcActionAttribute, TcActionGeneric, TcActionGenericBuffer,
-    TcActionMirror, TcActionMirrorOption, TcActionNat, TcActionNatOption,
-    TcActionOption, TcActionType, TcMirror, TcMirrorActionType, TcMirrorBuffer,
-    TcNat, TcNatBuffer, TcNatFlag,
+    TcActionMessage, TcActionMessageAttribute, TcActionMessageBuffer,
+    TcActionMessageFlags, TcActionMessageFlagsWithSelector, TcActionMirror,
+    TcActionMirrorOption, TcActionNat, TcActionNatOption, TcActionOption,
+    TcActionType, TcMirror, TcMirrorActionType, TcMirrorBuffer, TcNat,
+    TcNatBuffer, TcNatFlags,
 };
 pub use self::attribute::TcAttribute;
 pub use self::filters::{
     TcFilterMatchAll, TcFilterMatchAllOption, TcFilterU32, TcFilterU32Option,
-    TcU32Key, TcU32OptionFlag, TcU32Selector, TcU32SelectorFlag,
+    TcU32Key, TcU32OptionFlags, TcU32Selector, TcU32SelectorBuffer,
+    TcU32SelectorFlags,
 };
 pub use self::header::{TcHandle, TcHeader, TcMessageBuffer};
 pub use self::message::TcMessage;
